/*
   Speaker.cpp - Sound library for Arduino & Wiring
  Created by Gabriel Petrut, August 2, 2009.
  Released into the public domain.
*/

#include "WProgram.h"
#include "Speaker.h"

// Constructors ////////////////////////////////////////////////////////////////

Speaker::Speaker(byte pin)
{
  pinMode(pin, OUTPUT);
  _pin = pin;
}

// melody vaiables
byte names[] = {'c', 'd', 'e', 'f', 'g', 'a', 'b', 'C'};  
int tones[] = {1915, 1700, 1519, 1432, 1275, 1136, 1014, 956};


// Public Methods //////////////////////////////////////////////////////////////

void Speaker::PlayMelody(){
  int length = 15; // the number of notes
  byte notes[] = "ccggaagffeeddc "; // a space represents a rest
  int beats[] = { 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 2, 4 };
  int tempo = 300;
  
  for (int i = 0; i < length; i++) {
    if (notes[i] == ' ') {
       delay(beats[i] * tempo); // rest
     } 
     else {
       PlayNote(notes[i], beats[i] * tempo);
     }
   // pause between notes
   delay(tempo / 2); 
  }  
}

void Speaker::PlayTone(int tone, int duration) {
  for (long i = 0; i < duration * 1000L; i += tone * 2) {
    digitalWrite(_pin, HIGH);
    delayMicroseconds(tone);
    digitalWrite(_pin, LOW);
    delayMicroseconds(tone);
  }
}

void Speaker::PlayNote(byte note, int duration) {
  // play the tone corresponding to the note name
  for (int i = 0; i < 8; i++) {
    if (names[i] == note) {
      PlayTone(tones[i], duration);
    }
  }
} 

void Speaker::Beep(){
  unsigned long us;
  int duration_,i;
  int duration = 25000;
  int freq = 3000;
  us=(1000000/(freq*2));
  duration_ = (duration/(us*2));
  for (i=0;i<duration_;i++){
    digitalWrite(_pin,HIGH);
    delayMicroseconds(us);
    digitalWrite(_pin,LOW);
    delayMicroseconds(us);
  } 
} 